@@ -71,8 +71,9 @@ use log::info;
 use serde::Deserialize;
 
 use crate::{
+    CliError, CliResult,
     config::{Config, Delimiter},
-    util, CliError, CliResult,
+    util,
 };
 
 #[allow(dead_code)]
@@ -259,12 +260,13 @@ fn count_input(conf: &Config, count_delims_mode: CountDelimsMode) -> CliResult<(
 
     // if conf is indexed, we still get the count from the index
     let mut use_index_count = false;
-    let mut count = if let Some(idx) = conf.indexed()? {
-        use_index_count = true;
-        info!("index used");
-        idx.count()
-    } else {
-        0_u64
+    let mut count = match conf.indexed()? {
+        Some(idx) => {
+            use_index_count = true;
+            info!("index used");
+            idx.count()
+        },
+        _ => 0_u64,
     };
 
     let mut rdr = conf.reader()?;
@@ -343,7 +345,10 @@ fn count_input(conf: &Config, count_delims_mode: CountDelimsMode) -> CliResult<(
         // Calculate median width
         widths.par_sort_unstable();
         let median = if count % 2 == 0 {
-            (widths[(count / 2) as usize - 1] + widths[(count / 2) as usize]) / 2
+            usize::midpoint(
+                widths[(count / 2) as usize - 1],
+                widths[(count / 2) as usize],
+            )
         } else {
             widths[(count / 2) as usize]
         };
@@ -373,7 +378,10 @@ fn count_input(conf: &Config, count_delims_mode: CountDelimsMode) -> CliResult<(
                 .collect();
             abs_devs.par_sort_unstable_by(|a, b| a.partial_cmp(b).unwrap());
             if count % 2 == 0 {
-                (abs_devs[(count / 2) as usize - 1] + abs_devs[(count / 2) as usize]) / 2.0
+                f64::midpoint(
+                    abs_devs[(count / 2) as usize - 1],
+                    abs_devs[(count / 2) as usize],
+                )
             } else {
                 abs_devs[(count / 2) as usize]
             }
