@@ -113,11 +113,11 @@ use rayon::{
 use serde::Deserialize;
 
 use crate::{
+    CliResult,
     config::{Config, Delimiter},
     select::SelectColumns,
     util,
     util::replace_column_value,
-    CliResult,
 };
 
 #[allow(dead_code)]
@@ -279,30 +279,36 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         None => chrono_tz::UTC,
     };
 
-    let mut input_tz = if let Ok(tz) = args.flag_input_tz.parse::<Tz>() {
-        tz
-    } else if args.flag_input_tz.eq_ignore_ascii_case("local") {
-        if let Some(tz) = localzone::get_local_zone() {
-            log::info!("input-tz local timezone: {tz}");
-            tz.parse::<Tz>()?
-        } else {
-            default_tz
-        }
-    } else {
-        default_tz
+    let mut input_tz = match args.flag_input_tz.parse::<Tz>() {
+        Ok(tz) => tz,
+        _ => {
+            if args.flag_input_tz.eq_ignore_ascii_case("local") {
+                if let Some(tz) = localzone::get_local_zone() {
+                    log::info!("input-tz local timezone: {tz}");
+                    tz.parse::<Tz>()?
+                } else {
+                    default_tz
+                }
+            } else {
+                default_tz
+            }
+        },
     };
     #[allow(clippy::useless_let_if_seq)] // more readable this way
-    let mut output_tz = if let Ok(tz) = args.flag_output_tz.parse::<Tz>() {
-        tz
-    } else if args.flag_output_tz.eq_ignore_ascii_case("local") {
-        if let Some(tz) = localzone::get_local_zone() {
-            log::info!("output-tz local timezone: {tz}");
-            tz.parse::<Tz>()?
-        } else {
-            default_tz
-        }
-    } else {
-        default_tz
+    let mut output_tz = match args.flag_output_tz.parse::<Tz>() {
+        Ok(tz) => tz,
+        _ => {
+            if args.flag_output_tz.eq_ignore_ascii_case("local") {
+                if let Some(tz) = localzone::get_local_zone() {
+                    log::info!("output-tz local timezone: {tz}");
+                    tz.parse::<Tz>()?
+                } else {
+                    default_tz
+                }
+            } else {
+                default_tz
+            }
+        },
     };
 
     if args.flag_utc {
