@@ -61,7 +61,7 @@ use reqwest::blocking::Client;
 use serde::Deserialize;
 use serde_json::json;
 
-use crate::{util, util::process_input, CliResult};
+use crate::{CliResult, util, util::process_input};
 
 #[derive(Deserialize)]
 struct Args {
@@ -235,7 +235,12 @@ fn is_valid_model(
     } else {
         args.flag_model.clone().unwrap()
     };
-    let models = response_json["data"].as_array().unwrap();
+    let Some(models) = response_json["data"].as_array() else {
+        return fail_clierror!(
+            "Invalid response: 'data' field is not an array or is missing\n\n{}",
+            serde_json::to_string_pretty(&response_json).unwrap_or_default()
+        );
+    };
     for model in models {
         if model["id"].as_str().unwrap() == given_model {
             return Ok(true);
