@@ -41,8 +41,9 @@ Common options:
 use serde::Deserialize;
 
 use crate::{
+    CliResult,
     config::{Config, Delimiter},
-    util, CliResult,
+    util,
 };
 
 #[derive(Deserialize)]
