@@ -17,6 +17,8 @@ It supports seven sampling methods:
   specified by the <sample-size> argument. For example, if p=0.1, then each record
   has a 10% chance of being selected, regardless of the other records. The final
   sample size is random and follows a binomial distribution. Uses CONSTANT MEMORY - O(1).
+  When sampling from a remote URL that supports range requests, processes the file in
+  chunks without downloading it entirely, making it especially efficient for large remote files.
   https://en.wikipedia.org/wiki/Bernoulli_sampling
 
 - SYSTEMATIC: the sampling method when the --systematic option is specified.
@@ -155,27 +157,27 @@ use std::{
 };
 
 use rand::{
+    Rng, SeedableRng,
     distr::{Bernoulli, Distribution},
     prelude::IndexedRandom,
     rngs::StdRng,
-    Rng, SeedableRng,
 };
 use rand_hc::Hc128Rng;
 use rand_xoshiro::Xoshiro256Plus;
 use rayon::prelude::ParallelSliceMut;
+use reqwest;
 use serde::Deserialize;
 use strum_macros::EnumString;
 use tempfile::NamedTempFile;
 use url::Url;
 
 use crate::{
+    CliResult,
     config::{Config, Delimiter},
     select::SelectColumns,
     util,
-    util::{get_stats_records, SchemaArgs, StatsMode},
-    CliResult,
+    util::{SchemaArgs, StatsMode, get_stats_records},
 };
-
 #[derive(Deserialize)]
 struct Args {
     arg_input:       Option<String>,
@@ -263,6 +265,7 @@ enum RngKind {
     Cryptosecure,
 }
 
+#[derive(PartialEq)]
 enum SamplingMethod {
     Bernoulli,
     Systematic,
@@ -341,83 +344,117 @@ fn check_stats_cache(
     };
 
     // Get stats records
-    if let Ok((csv_fields, stats, dataset_stats)) =
-        get_stats_records(&schema_args, StatsMode::Frequency)
-    {
-        // Get row count from stats cache
-        let rowcount = dataset_stats
-            .get("qsv__rowcount")
-            .and_then(|rc| rc.parse::<f64>().ok())
-            .map(|rc| rc as u64);
+    match get_stats_records(&schema_args, StatsMode::Frequency) {
+        Ok((csv_fields, stats, dataset_stats)) => {
+            // Get row count from stats cache
+            let rowcount = dataset_stats
+                .get("qsv__rowcount")
+                .and_then(|rc| rc.parse::<f64>().ok())
+                .map(|rc| rc as u64);
 
-        let mut max_weight = None;
-        let mut cardinality = None;
-        match method {
-            SamplingMethod::Weighted => {
-                // For weighted sampling, get max weight
-                max_weight = if let Some(weight_col) = &args.flag_weighted {
-                    let idx = if weight_col.chars().all(char::is_numeric) {
-                        weight_col.parse::<usize>().ok()
-                    } else {
-                        csv_fields
-                            .iter()
-                            .position(|field| field == weight_col.as_bytes())
-                    };
+            let mut max_weight = None;
+            let mut cardinality = None;
+            match method {
+                SamplingMethod::Weighted => {
+                    // For weighted sampling, get max weight
+                    max_weight = if let Some(weight_col) = &args.flag_weighted {
+                        let idx = if weight_col.chars().all(char::is_numeric) {
+                            weight_col.parse::<usize>().ok()
+                        } else {
+                            csv_fields
+                                .iter()
+                                .position(|field| field == weight_col.as_bytes())
+                        };
 
-                    if let Some(idx) = idx {
-                        if let Some(col_stats) = stats.get(idx) {
-                            let min_weight = col_stats
-                                .min
-                                .clone()
-                                .unwrap()
-                                .parse::<f64>()
-                                .unwrap_or_default();
-                            if min_weight < 0.0 {
-                                return fail_incorrectusage_clierror!(
-                                    "Weights must be non-negative. Lowest weight: {min_weight}"
-                                );
+                        if let Some(idx) = idx {
+                            if let Some(col_stats) = stats.get(idx) {
+                                let min_weight = col_stats
+                                    .min
+                                    .clone()
+                                    .unwrap()
+                                    .parse::<f64>()
+                                    .unwrap_or_default();
+                                if min_weight < 0.0 {
+                                    return fail_incorrectusage_clierror!(
+                                        "Weights must be non-negative. Lowest weight: {min_weight}"
+                                    );
+                                }
+
+                                col_stats.max.clone().unwrap().parse::<f64>().ok()
+                            } else {
+                                None
                             }
-
-                            col_stats.max.clone().unwrap().parse::<f64>().ok()
                         } else {
                             None
                         }
                     } else {
                         None
-                    }
-                } else {
-                    None
-                };
-            },
-            SamplingMethod::Cluster => {
-                // For cluster sampling, get cardinality
-                cardinality = if let Some(cluster_col) = &args.flag_cluster {
-                    let idx = if cluster_col.chars().all(char::is_numeric) {
-                        cluster_col.parse::<usize>().ok()
-                    } else {
-                        csv_fields
-                            .iter()
-                            .position(|field| field == cluster_col.as_bytes())
                     };
+                },
+                SamplingMethod::Cluster => {
+                    // For cluster sampling, get cardinality
+                    cardinality = if let Some(cluster_col) = &args.flag_cluster {
+                        let idx = if cluster_col.chars().all(char::is_numeric) {
+                            cluster_col.parse::<usize>().ok()
+                        } else {
+                            csv_fields
+                                .iter()
+                                .position(|field| field == cluster_col.as_bytes())
+                        };
 
-                    if let Some(idx) = idx {
-                        stats.get(idx).map(|col_stats| col_stats.cardinality)
+                        if let Some(idx) = idx {
+                            stats.get(idx).map(|col_stats| col_stats.cardinality)
+                        } else {
+                            None
+                        }
                     } else {
                         None
-                    }
-                } else {
-                    None
-                };
-            },
-            _ => {},
-        }
+                    };
+                },
+                _ => {},
+            }
 
-        Ok((rowcount, max_weight, cardinality))
-    } else {
-        Ok((None, None, None))
+            Ok((rowcount, max_weight, cardinality))
+        },
+        _ => Ok((None, None, None)),
     }
 }
 
+/// Checks if a URL supports range requests and returns the content length if available
+async fn check_range_support(
+    url: &str,
+    client: &reqwest::Client,
+) -> CliResult<(bool, Option<u64>)> {
+    let res = client.head(url).send().await?;
+
+    // Check if server supports range requests
+    let supports_range = res
+        .headers()
+        .get("Accept-Ranges")
+        .is_some_and(|v| v.as_bytes() == b"bytes");
+
+    let content_length = res.content_length();
+
+    Ok((supports_range, content_length))
+}
+
+/// Fetches a specific range of bytes from a URL
+async fn fetch_range(
+    url: &str,
+    client: &reqwest::Client,
+    start: u64,
+    end: u64,
+) -> CliResult<Vec<u8>> {
+    let range_header = format!("bytes={start}-{end}");
+    let res = client.get(url).header("Range", range_header).send().await?;
+
+    if !res.status().is_success() {
+        return fail_clierror!("Failed to fetch range: HTTP {}", res.status());
+    }
+
+    Ok(res.bytes().await?.to_vec())
+}
+
 pub fn run(argv: &[&str]) -> CliResult<()> {
     let mut args: Args = util::get_args(USAGE, argv)?;
 
@@ -468,11 +505,121 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             let max_size_bytes = args.flag_max_size.map(|mb| mb * 1024 * 1024);
 
             // its a remote file, download it first
+            // Setup reqwest client
+            let client = reqwest::Client::builder()
+                .user_agent(util::set_user_agent(user_agent.clone())?)
+                .timeout(std::time::Duration::from_secs(
+                    util::timeout_secs(args.flag_timeout.unwrap_or(30)).unwrap_or(30),
+                ))
+                .build()?;
+
+            // Check if server supports range requests
+            let rt = tokio::runtime::Runtime::new()?;
+            let (supports_range, content_length) =
+                rt.block_on(check_range_support(&uri, &client))?;
+
+            // For bernoulli sampling with remote file with host that supports range requests
+            // handle specially
+            if supports_range
+                && content_length.is_some()
+                && sampling_method == SamplingMethod::Bernoulli
+            {
+                log::info!("Bernoulli sampling remote file with host that supports range requests");
+                let default_delim = match std::env::var("QSV_DEFAULT_DELIMITER") {
+                    Ok(delim) => Delimiter::decode_delimiter(&delim).unwrap().as_byte(),
+                    _ => b',',
+                };
+
+                // First download a small chunk to get headers and CSV structure
+                let initial_bytes = rt.block_on(fetch_range(&uri, &client, 0, 16384))?;
+                std::fs::write(&temp_download, &initial_bytes)?;
+
+                // Create temporary config to read headers
+                let temp_config =
+                    Config::new(Some(&temp_download.path().to_str().unwrap().to_string()))
+                        .delimiter(args.flag_delimiter)
+                        .no_headers(args.flag_no_headers)
+                        .flexible(true);
+
+                let mut temp_rdr = temp_config.reader()?;
+                let headers = if args.flag_no_headers {
+                    None
+                } else {
+                    Some((*temp_rdr.headers()?).clone())
+                };
+
+                // Create output writer
+                let mut wtr = Config::new(args.flag_output.as_ref())
+                    .delimiter(args.flag_delimiter)
+                    .writer()?;
+
+                // Write headers if present
+                if let Some(headers) = headers {
+                    wtr.write_record(&headers)?;
+                }
+
+                let total_size = content_length.unwrap();
+
+                let mut std_rng = StandardRng::create(args.flag_seed);
+                let mut faster_rng = FasterRng::create(args.flag_seed);
+                let mut crypto_rng = CryptoRng::create(args.flag_seed);
+
+                // Process in chunks
+                let chunk_size = 4 * 1024 * 1024; // 4MB chunks
+                let mut offset = if args.flag_no_headers {
+                    0
+                } else {
+                    initial_bytes.len() as u64
+                };
+
+                let mut record = csv::ByteRecord::new();
+
+                while offset < total_size {
+                    let end = std::cmp::min(offset + chunk_size, total_size);
+                    let chunk = rt.block_on(fetch_range(&uri, &client, offset, end))?;
+
+                    // Process chunk with bernoulli sampling
+                    let mut chunk_rdr = csv::ReaderBuilder::new()
+                        .has_headers(false)
+                        .delimiter(default_delim)
+                        .from_reader(chunk.as_slice());
+
+                    match rng_kind {
+                        RngKind::Standard => {
+                            while chunk_rdr.read_byte_record(&mut record)? {
+                                if std_rng.random_bool(args.arg_sample_size) {
+                                    wtr.write_byte_record(&record)?;
+                                }
+                            }
+                        },
+                        RngKind::Faster => {
+                            while chunk_rdr.read_byte_record(&mut record)? {
+                                if faster_rng.random_bool(args.arg_sample_size) {
+                                    wtr.write_byte_record(&record)?;
+                                }
+                            }
+                        },
+                        RngKind::Cryptosecure => {
+                            while chunk_rdr.read_byte_record(&mut record)? {
+                                if crypto_rng.random_bool(args.arg_sample_size) {
+                                    wtr.write_byte_record(&record)?;
+                                }
+                            }
+                        },
+                    }
+
+                    offset = end + 1;
+                }
+
+                return Ok(wtr.flush()?);
+            }
+
+            // For other cases or when range requests not supported, download entire file
             let future = util::download_file(
                 &uri,
                 temp_download.path().to_path_buf(),
                 false,
-                user_agent,
+                Some(util::set_user_agent(user_agent)?),
                 args.flag_timeout,
                 max_size_bytes,
             );
@@ -522,7 +669,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                 Some(_) => {
                     return fail_incorrectusage_clierror!(
                         "Systematic sampling starting point must be either 'random' or 'first'"
-                    )
+                    );
                 },
                 None => String::from("random"),
             };
@@ -530,10 +677,15 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             let (rowcount_stats, _, _) = check_stats_cache(&args, &SamplingMethod::Systematic)?;
             let row_count = if let Some(rc) = rowcount_stats {
                 rc
-            } else if let Ok(rc) = util::count_rows(&rconfig) {
-                rc
             } else {
-                return fail!("Cannot get rowcount. Systematic sampling requires a rowcount.");
+                match util::count_rows(&rconfig) {
+                    Ok(rc) => rc,
+                    _ => {
+                        return fail!(
+                            "Cannot get rowcount. Systematic sampling requires a rowcount."
+                        );
+                    },
+                }
             };
 
             sample_systematic(
@@ -656,13 +808,19 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
 
                     if let Some(rc) = rowcount_stats {
                         (rc as f64 * args.arg_sample_size).round() as u64
-                    } else if let Ok(rc) = util::count_rows(&rconfig) {
-                        // we don't have a stats cache, get the rowcount the "regular" way
-                        (rc as f64 * args.arg_sample_size).round() as u64
                     } else {
-                        return fail!(
-                            "Cannot get rowcount. Percentage sampling requires a rowcount."
-                        );
+                        match util::count_rows(&rconfig) {
+                            Ok(rc) => {
+                                // we don't have a stats cache, get the rowcount the "regular"
+                                // way
+                                (rc as f64 * args.arg_sample_size).round() as u64
+                            },
+                            _ => {
+                                return fail!(
+                                    "Cannot get rowcount. Percentage sampling requires a rowcount."
+                                );
+                            },
+                        }
                     }
                 } else {
                     args.arg_sample_size as u64
