@@ -201,8 +201,8 @@ use std::{
     io::{BufReader, BufWriter, Read, Write},
     str,
     sync::{
-        atomic::{AtomicU16, Ordering},
         OnceLock,
+        atomic::{AtomicU16, Ordering},
     },
 };
 
@@ -212,9 +212,9 @@ use indicatif::HumanCount;
 #[cfg(any(feature = "feature_capable", feature = "lite"))]
 use indicatif::{ProgressBar, ProgressDrawTarget};
 use jsonschema::{
+    Keyword, ValidationError, Validator,
     output::BasicOutput,
     paths::{LazyLocation, Location},
-    Keyword, ValidationError, Validator,
 };
 use log::{debug, info, log_enabled};
 use qsv_currency::Currency;
@@ -223,17 +223,18 @@ use rayon::{
     prelude::IntoParallelRefIterator,
 };
 use serde::{Deserialize, Serialize};
-use serde_json::{json, value::Number, Map, Value};
+use serde_json::{Map, Value, json, value::Number};
 #[cfg(feature = "lite")]
 use tempfile::NamedTempFile;
 
 #[cfg(not(feature = "lite"))]
 use crate::lookup;
 #[cfg(not(feature = "lite"))]
-use crate::lookup::{load_lookup_table, LookupTableOptions};
+use crate::lookup::{LookupTableOptions, load_lookup_table};
 use crate::{
-    config::{Config, Delimiter, DEFAULT_WTR_BUFFER_CAPACITY},
-    util, CliError, CliResult,
+    CliError, CliResult,
+    config::{Config, DEFAULT_WTR_BUFFER_CAPACITY, Delimiter},
+    util,
 };
 
 // to save on repeated init/allocs
@@ -628,6 +629,7 @@ fn test_parse_dynenum_uri() {
 /// * `Ok(Box<DynEnumValidator>)` - Validator initialized with values from first CSV column
 /// * `Err(ValidationError)` - If loading/parsing CSV fails or value is not a string
 #[cfg(not(feature = "lite"))]
+#[allow(clippy::result_large_err)]
 fn dyn_enum_validator_factory<'a>(
     _parent: &'a Map<String, Value>,
     value: &'a Value,
@@ -691,7 +693,7 @@ fn dyn_enum_validator_factory<'a>(
                             return fail_validation_error!(
                                 "Column '{}' not found in lookup table",
                                 col_name
-                            )
+                            );
                         },
                     }
                 },
@@ -717,6 +719,7 @@ fn dyn_enum_validator_factory<'a>(
 }
 
 #[cfg(feature = "lite")]
+#[allow(clippy::result_large_err)]
 fn dyn_enum_validator_factory<'a>(
     _parent: &'a Map<String, Value>,
     value: &'a Value,
@@ -1467,7 +1470,7 @@ fn to_json_instance(
                     return fail_clierror!(
                         "Can't cast into Number. key: {key}, value: {}",
                         String::from_utf8_lossy(value)
-                    )
+                    );
                 },
             },
             JSONtypes::Integer => match atoi_simd::parse::<i64>(value) {
@@ -1476,7 +1479,7 @@ fn to_json_instance(
                     return fail_clierror!(
                         "Can't cast into Integer. key: {key}, value: {}",
                         String::from_utf8_lossy(value)
-                    )
+                    );
                 },
             },
             JSONtypes::Boolean => match value {
@@ -1486,7 +1489,7 @@ fn to_json_instance(
                     return fail_clierror!(
                         "Can't cast into Boolean. key: {key}, value: {}",
                         String::from_utf8_lossy(value)
-                    )
+                    );
                 },
             },
             JSONtypes::Unsupported => unreachable!("we should never get an unsupported JSON type"),
@@ -2061,12 +2064,15 @@ fn test_dyn_enum_validator() {
     assert!(!validator.is_valid(&json!("bananana")));
     assert!(!validator.is_valid(&json!("")));
     assert!(!validator.is_valid(&json!(5)));
-    if let Err(e) = validator.validate(&json!("lanzones")) {
-        assert_eq!(
-            format!("{e:?}"),
-            r#"ValidationError { instance: String("lanzones"), kind: Custom { message: "\"lanzones\" is not a valid dynamicEnum value" }, instance_path: Location(""), schema_path: Location("") }"#
-        );
-    } else {
-        unreachable!("Expected an error, but validation succeeded.");
+    match validator.validate(&json!("lanzones")) {
+        Err(e) => {
+            assert_eq!(
+                format!("{e:?}"),
+                r#"ValidationError { instance: String("lanzones"), kind: Custom { message: "\"lanzones\" is not a valid dynamicEnum value" }, instance_path: Location(""), schema_path: Location("") }"#
+            );
+        },
+        _ => {
+            unreachable!("Expected an error, but validation succeeded.");
+        },
     };
 }
