@@ -6,7 +6,7 @@ use rand::Rng;
 use serde::Deserialize;
 
 use crate::{
-    clitypes::{CliError, CliResult, QsvExitCode, CURRENT_COMMAND},
+    clitypes::{CURRENT_COMMAND, CliError, CliResult, QsvExitCode},
     config::SPONSOR_MESSAGE,
 };
 
