@@ -157,7 +157,9 @@ fn safenames_verify_verbose() {
                 "col1",
                 "_1",
             ],
-            svec!["1", "b", "33", "1", "b", "33", "34", "z", "42", "3", "2", "1", "0"],
+            svec![
+                "1", "b", "33", "1", "b", "33", "34", "z", "42", "3", "2", "1", "0"
+            ],
         ],
     );
 
@@ -205,7 +207,9 @@ fn safenames_verify_verbose_pretty_json() {
                 "col1",
                 "_1",
             ],
-            svec!["1", "b", "33", "1", "b", "33", "34", "z", "42", "3", "2", "1", "0"],
+            svec![
+                "1", "b", "33", "1", "b", "33", "34", "z", "42", "3", "2", "1", "0"
+            ],
         ],
     );
 
@@ -287,7 +291,9 @@ fn safenames_verify_verbose_json() {
                 "col1",
                 "_1",
             ],
-            svec!["1", "b", "33", "1", "b", "33", "34", "z", "42", "3", "2", "1", "0"],
+            svec![
+                "1", "b", "33", "1", "b", "33", "34", "z", "42", "3", "2", "1", "0"
+            ],
         ],
     );
 
