@@ -1,8 +1,8 @@
 use crate::workdir::Workdir;
 
 macro_rules! select_test {
-    ($name:ident, $select:expr, $select_no_headers:expr,
-     $expected_headers:expr, $expected_rows:expr) => {
+    ($name:ident, $select:expr_2021, $select_no_headers:expr_2021,
+     $expected_headers:expr_2021, $expected_rows:expr_2021) => {
         mod $name {
             use super::data;
             use crate::workdir::Workdir;
@@ -39,10 +39,12 @@ macro_rules! select_test {
                     .arg("data.csv");
                 let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
 
-                let expected = vec![$expected_rows
-                    .iter()
-                    .map(|s| s.to_string())
-                    .collect::<Vec<String>>()];
+                let expected = vec![
+                    $expected_rows
+                        .iter()
+                        .map(|s| s.to_string())
+                        .collect::<Vec<String>>(),
+                ];
                 assert_eq!(got, expected);
             }
         }
@@ -50,7 +52,7 @@ macro_rules! select_test {
 }
 
 macro_rules! select_test_err {
-    ($name:ident, $select:expr) => {
+    ($name:ident, $select:expr_2021) => {
         #[test]
         fn $name() {
             let wrk = Workdir::new(stringify!($name));
