@@ -4,7 +4,7 @@ use assert_json_diff::assert_json_eq;
 
 // use postgres::{Client, NoTls};
 // use rusqlite::Connection;
-use crate::workdir::{is_same_file, Workdir};
+use crate::workdir::{Workdir, is_same_file};
 
 #[test]
 fn to_xlsx_roundtrip() {
